==> owncloud-4.5.7.tgz: owncloud/apps/calendar/l10n/lt_LT.php <==
<?php $TRANSLATIONS = array(
"No calendars found." => "Kalendorių nerasta.",
"No events found." => "Įvykių nerasta.",
"Wrong calendar" => "Ne tas kalendorius",
"New Timezone:" => "Nauja laiko juosta:",
"Timezone changed" => "Laiko zona pakeista",
"Invalid request" => "Klaidinga užklausa",
"Calendar" => "Kalendorius",
"Editable" => "Redaguojamas",
"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}",
"Birthday" => "Gimtadienis",
"Business" => "Verslas",
"Call" => "Skambučiai",
"Clients" => "Klientai",
"Deliverer" => "Vykdytojas",
"Holidays" => "Išeiginės",
"Ideas" => "Idėjos",
"Journey" => "Kelionė",
"Jubilee" => "Jubiliejus",
"Meeting" => "Susitikimas",
"Other" => "Kiti",
"Personal" => "Asmeniniai",
"Projects" => "Projektai",
"Questions" => "Klausimai",
"Work" => "Darbas",
"unnamed" => "be pavadinimo",
"New Calendar" => "Naujas kalendorius",
"Does not repeat" => "Nekartoti",
"Daily" => "Kasdien",
"Weekly" => "Kiekvieną savaitę",
"Every Weekday" => "Kiekvieną savaitės dieną",
"Bi-Weekly" => "Kas dvi savaites",
"Monthly" => "Kiekvieną mėnesį",
"Yearly" => "Kiekvienais metais",
"never" => "niekada",
"by date" => "pagal datą",
"by monthday" => "pagal mėnesio dieną",
"by weekday" => "pagal savaitės dieną",
"Monday" => "Pirmadienis",
"Tuesday" => "Antradienis",
"Wednesday" => "Trečiadienis",
"Thursday" => "Ketvirtadienis",
"Friday" => "Penktadienis",
"Saturday" => "Šeštadienis",
"Sunday" => "Sekmadienis",
"January" => "Sausis",
"February" => "Vasaris",
"March" => "Kovas",
"April" => "Balandis",
"May" => "Gegužė",
"June" => "Birželis",
"July" => "Liepa",
"August" => "Rugpjūtis",
"September" => "Rugsėjis",
"October" => "Spalis",
"November" => "Lapkritis",
"December" => "Gruodis",
"Date" => "Data",
"Cal." => "Kal.",
"All day" => "Visa diena",
"Missing fields" => "Trūkstami laukai",
"Title" => "Pavadinimas",
"From Date" => "Nuo datos",
"From Time" => "Nuo laiko",
"To Date" => "Iki datos",
"To Time" => "Iki laiko",
"The event ends before it starts" => "Įvykis baigiasi anksčiau nei jis prasideda",
"There was a database fail" => "Įvyko duomenų bazės klaida",
"Week" => "Savaitė",
"Month" => "Mėnuo",
"List" => "Sąrašas",
"Today" => "Šiandien",
"Your calendars" => "Jūsų kalendoriai",
"CalDav Link" => "CalDav adresas",
"Share Calendar" => "Dalintis kalendoriumi",
"Download" => "Atsisiųsti",
"Edit" => "Keisti",
"Delete" => "Trinti",
"New calendar" => "Naujas kalendorius",
"Edit calendar" => "Taisyti kalendorių",
"Displayname" => "Pavadinimas",
"Active" => "Naudojamas",
"Calendar color" => "Kalendoriaus spalva",
"Save" => "Išsaugoti",
"Submit" => "Išsaugoti",
"Cancel" => "Atšaukti",
"Edit an event" => "Taisyti įvykį",
"Export" => "Eksportuoti",
"Eventinfo" => "Informacija",
"Repeating" => "Pasikartojantis",
"Alarm" => "Priminimas",
"Attendees" => "Dalyviai",
"Share" => "Dalintis",
"Title of the Event" => "Įvykio pavadinimas",
"Category" => "Kategorija",
"Separate categories with commas" => "Atskirkite kategorijas kableliais",
"Edit categories" => "Redaguoti kategorijas",
"All Day Event" => "Visos dienos įvykis",
"From" => "Nuo",
"To" => "Iki",
"Advanced options" => "Papildomi nustatymai",
"Location" => "Vieta",
"Location of the Event" => "Įvykio vieta",
"Description" => "Aprašymas",
"Description of the Event" => "Įvykio aprašymas",
"Repeat" => "Kartoti",
"Select weekdays" => "Pasirinkite savaitės dienas",
"Select days" => "Pasirinkite dienas",
"Select months" => "Pasirinkite mėnesius",
"Select weeks" => "Pasirinkite savaites",
"Interval" => "Intervalas",
"End" => "Pabaiga",
"create a new calendar" => "sukurti naują kalendorių",
"Import a calendar file" => "Importuoti kalendoriaus failą",
"Name of new calendar" => "Naujo kalendoriaus pavadinimas",
"Import" => "Importuoti",
"Close Dialog" => "Uždaryti",
"Create a new event" => "Sukurti naują įvykį",
"View an event" => "Peržiūrėti įvykį",
"No categories selected" => "Nepasirinktos jokios katagorijos",
"Timezone" => "Laiko juosta",
"24h" => "24val",
"12h" => "12val"
);

==> owncloud-5.0.9.tgz: owncloud/apps/calendar/l10n/lt_LT.php <==
<?php $TRANSLATIONS = array(
"No calendars found." => "Kalendorių nerasta.",
"No events found." => "Įvykių nerasta.",
"Wrong calendar" => "Ne tas kalendorius",
"New Timezone:" => "Nauja laiko juosta:",
"Timezone changed" => "Laiko zona pakeista",
"Invalid request" => "Klaidinga užklausa",
"Calendar" => "Kalendorius",
"Deletion failed" => "Ištrinti nepavyko",
"Editable" => "Redaguojamas",
"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}",
"Sunday" => "Sekmadienis",
"Monday" => "Pirmadienis",
"Tuesday" => "Antradienis",
"Wednesday" => "Trečiadienis",
"Thursday" => "Ketvirtadienis",
"Friday" => "Penktadienis",
"Saturday" => "Šeštadienis",
"Sun." => "Sek.",
"Mon." => "Pr.",
"Tue." => "An.",
"Wed." => "Tr.",
"Thu." => "Ket.",
"Fri." => "Pen.",
"Sat." => "Šešt.",
"January" => "Sausis",
"February" => "Vasaris",
"March" => "Kovas",
"April" => "Balandis",
"May" => "Gegužė",
"June" => "Birželis",
"July" => "Liepa",
"August" => "Rugpjūtis",
"September" => "Rugsėjis",
"October" => "Spalis",
"November" => "Lapkritis",
"December" => "Gruodis",
"Jan." => "Sau.",
"Feb." => "Vas.",
"Mar." => "Kov.",
"Apr." => "Bal.",
"May." => "Geg.",
"Jun." => "Bir.",
"Jul." => "Lie.",
"Aug." => "Rugp.",
"Sep." => "Rugs.",
"Oct." => "Spa.",
"Nov." => "Lap.",
"Dec." => "Groud.",
"All day" => "Visa diena",
"New Calendar" => "Naujas kalendorius",
"Title" => "Pavadinimas",
"From Date" => "Nuo datos",
"From Time" => "Nuo laiko",
"To Date" => "Iki datos",
"To Time" => "Iki laiko",
"The event ends before it starts" => "Įvykis baigiasi anksčiau nei jis prasideda",
"There was a database fail" => "Įvyko duomenų bazės klaida",
"Birthday" => "Gimtadienis",
"Business" => "Verslas",
"Call" => "Skambučiai",
"Clients" => "Klientai",
"Deliverer" => "Vykdytojas",
"Holidays" => "Išeiginės",
"Ideas" => "Idėjos",
"Journey" => "Kelionė",
"Jubilee" => "Jubiliejus",
"Meeting" => "Susitikimas",
"Other" => "Kiti",
"Personal" => "Asmeniniai",
"Projects" => "Projektai",
"Questions" => "Klausimai",
"Work" => "Darbas",
"unnamed" => "be pavadinimo",
"Does not repeat" => "Nekartoti",
"Daily" => "Kasdien",
"Weekly" => "Kiekvieną savaitę",
"Every Weekday" => "Kiekvieną savaitės dieną",
"Bi-Weekly" => "Kas dvi savaites",
"Monthly" => "Kiekvieną mėnesį",
"Yearly" => "Kiekvienais metais",
"never" => "niekada",
"by date" => "pagal datą",
"by monthday" => "pagal mėnesio dieną",
"by weekday" => "pagal savaitės dieną",
"Date" => "Data",
"Cal." => "Kal.",
"Week" => "Savaitė",
"Month" => "Mėnuo",
"List" => "Sąrašas",
"Today" => "Šiandien",
"Settings" => "Nustatymai",
"Your calendars" => "Jūsų kalendoriai",
"CalDav Link" => "CalDav adresas",
"Share Calendar" => "Dalintis kalendoriumi",
"Download" => "Atsisiųsti",
"Edit" => "Keisti",
"Delete" => "Trinti",
"New calendar" => "Naujas kalendorius",
"Edit calendar" => "Taisyti kalendorių",
"Displayname" => "Pavadinimas",
"Active" => "Naudojamas",
"Calendar color" => "Kalendoriaus spalva",
"Save" => "Išsaugoti",
"Submit" => "Išsaugoti",
"Cancel" => "Atšaukti",
"Edit an event" => "Taisyti įvykį",
"Export" => "Eksportuoti",
"Eventinfo" => "Informacija",
"Repeating" => "Pasikartojantis",
"Alarm" => "Priminimas",
"Attendees" => "Dalyviai",
"Share" => "Dalintis",
"Title of the Event" => "Įvykio pavadinimas",
"Category" => "Kategorija",
"Separate categories with commas" => "Atskirkite kategorijas kableliais",
"Edit categories" => "Redaguoti kategorijas",
"All Day Event" => "Visos dienos įvykis",
"From" => "Nuo",
"To" => "Iki",
"Advanced options" => "Papildomi nustatymai",
"Location" => "Vieta",
"Location of the Event" => "Įvykio vieta",
"Description" => "Aprašymas",
"Description of the Event" => "Įvykio aprašymas",
"Repeat" => "Kartoti",
"Select weekdays" => "Pasirinkite savaitės dienas",
"Select days" => "Pasirinkite dienas",
"Select months" => "Pasirinkite mėnesius",
"Select weeks" => "Pasirinkite savaites",
"Interval" => "Intervalas",
"End" => "Pabaiga",
"create a new calendar" => "sukurti naują kalendorių",
"Import a calendar file" => "Importuoti kalendoriaus failą",
"Name of new calendar" => "Naujo kalendoriaus pavadinimas",
"Import" => "Importuoti",
"Close Dialog" => "Uždaryti",
"Create a new event" => "Sukurti naują įvykį",
"Unshare" => "Nebesidalinti",
"View an event" => "Peržiūrėti įvykį",
"No categories selected" => "Nepasirinktos jokios katagorijos",
"Timezone" => "Laiko juosta",
"24h" => "24val",
"12h" => "12val"
);
